@@ -84,11 +84,11 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	vala_ccode_writer_write_begin_block (writer);
 	first = TRUE;
 	{
-		GeeIterator* value_it;
-		value_it = gee_iterable_iterator ((GeeIterable*) self->priv->values);
-		while (gee_iterator_next (value_it)) {
+		GeeIterator* _value_it;
+		_value_it = gee_iterable_iterator ((GeeIterable*) self->priv->values);
+		while (gee_iterator_next (_value_it)) {
 			ValaCCodeEnumValue* value;
-			value = (ValaCCodeEnumValue*) gee_iterator_get (value_it);
+			value = (ValaCCodeEnumValue*) gee_iterator_get (_value_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ",");
 				vala_ccode_writer_write_newline (writer);
@@ -98,7 +98,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 			first = FALSE;
 			(value == NULL) ? NULL : (value = (vala_ccode_node_unref (value), NULL));
 		}
-		(value_it == NULL) ? NULL : (value_it = (gee_collection_object_unref (value_it), NULL));
+		(_value_it == NULL) ? NULL : (_value_it = (gee_collection_object_unref (_value_it), NULL));
 	}
 	if (!first) {
 		vala_ccode_writer_write_newline (writer);
