@@ -155,14 +155,14 @@ static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointe
 			} else {
 				_tmp1 = !self->priv->_equal_func ((*node)->key, key);
 			}
-			_tmp0 = (_tmp1);
+			_tmp0 = _tmp1;
 		} else {
 			_tmp0 = FALSE;
 		}
 		if (!_tmp0) {
 			break;
 		}
-		node = &((*node)->next);
+		node = &(*node)->next;
 	}
 	return node;
 }
@@ -173,7 +173,7 @@ static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer k
 	GeeHashSetNode** node;
 	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
-	return ((*node) != NULL);
+	return (*node) != NULL;
 }
 
 
@@ -276,7 +276,7 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 	} else {
 		_tmp1 = FALSE;
 	}
-	if ((_tmp1)) {
+	if (_tmp1) {
 		_tmp0 = TRUE;
 	} else {
 		gboolean _tmp2;
@@ -286,7 +286,7 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 		} else {
 			_tmp2 = FALSE;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	}
 	if (_tmp0) {
 		gint new_array_size;
@@ -426,7 +426,7 @@ static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_set->priv->_nodes[self->priv->_index];
 	}
-	return (self->priv->_node != NULL);
+	return self->priv->_node != NULL;
 }
 
 
