@@ -72,7 +72,7 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 			}
 			goto __finally0;
 		}
-		return (_tmp0 = (0 == exit_status), pc = (g_free (pc), NULL), _tmp0);
+		return (_tmp0 = 0 == exit_status, pc = (g_free (pc), NULL), _tmp0);
 	}
 	goto __finally0;
 	__catch0_g_spawn_error:
@@ -112,10 +112,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	const char* _tmp11;
 	char* cmdline;
 	gboolean _tmp21;
+	gboolean _tmp22;
 	GeeList* source_files;
 	GeeList* c_source_files;
+	char* _tmp34;
 	char* _tmp33;
-	char* _tmp32;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (context != NULL);
 	inner_error = NULL;
@@ -123,14 +124,14 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	if (!vala_code_context_get_compile_only (context)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		pc = (_tmp0 = g_strconcat (pc, (" --libs"), NULL), pc = (g_free (pc), NULL), _tmp0);
+		pc = (_tmp0 = g_strconcat (pc, " --libs", NULL), pc = (g_free (pc), NULL), _tmp0);
 	}
 	_tmp1 = NULL;
-	pc = (_tmp1 = g_strconcat (pc, (" gobject-2.0"), NULL), pc = (g_free (pc), NULL), _tmp1);
+	pc = (_tmp1 = g_strconcat (pc, " gobject-2.0", NULL), pc = (g_free (pc), NULL), _tmp1);
 	if (vala_code_context_get_thread (context)) {
 		char* _tmp2;
 		_tmp2 = NULL;
-		pc = (_tmp2 = g_strconcat (pc, (" gthread-2.0"), NULL), pc = (g_free (pc), NULL), _tmp2);
+		pc = (_tmp2 = g_strconcat (pc, " gthread-2.0", NULL), pc = (g_free (pc), NULL), _tmp2);
 	}
 	{
 		GeeList* _tmp3;
@@ -147,7 +148,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 				char* _tmp5;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
-				pc = (_tmp6 = g_strconcat (pc, _tmp5 = (g_strconcat (" ", pkg, NULL)), NULL), pc = (g_free (pc), NULL), _tmp6);
+				pc = (_tmp6 = g_strconcat (pc, _tmp5 = g_strconcat (" ", pkg, NULL), NULL), pc = (g_free (pc), NULL), _tmp6);
 				_tmp5 = (g_free (_tmp5), NULL);
 			}
 			pkg = (g_free (pkg), NULL);
@@ -212,12 +213,12 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	if (vala_code_context_get_debug (context)) {
 		char* _tmp12;
 		_tmp12 = NULL;
-		cmdline = (_tmp12 = g_strconcat (cmdline, (" -g"), NULL), cmdline = (g_free (cmdline), NULL), _tmp12);
+		cmdline = (_tmp12 = g_strconcat (cmdline, " -g", NULL), cmdline = (g_free (cmdline), NULL), _tmp12);
 	}
 	if (vala_code_context_get_compile_only (context)) {
 		char* _tmp13;
 		_tmp13 = NULL;
-		cmdline = (_tmp13 = g_strconcat (cmdline, (" -c"), NULL), cmdline = (g_free (cmdline), NULL), _tmp13);
+		cmdline = (_tmp13 = g_strconcat (cmdline, " -c", NULL), cmdline = (g_free (cmdline), NULL), _tmp13);
 	} else {
 		if (vala_code_context_get_output (context) != NULL) {
 			const char* _tmp14;
@@ -249,29 +250,35 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			_tmp20 = NULL;
 			_tmp19 = NULL;
 			_tmp18 = NULL;
-			cmdline = (_tmp20 = g_strconcat (cmdline, _tmp19 = (g_strconcat (" -o ", _tmp18 = g_shell_quote (output), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp20);
+			cmdline = (_tmp20 = g_strconcat (cmdline, _tmp19 = g_strconcat (" -o ", _tmp18 = g_shell_quote (output), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp20);
 			_tmp19 = (g_free (_tmp19), NULL);
 			_tmp18 = (g_free (_tmp18), NULL);
 			output = (g_free (output), NULL);
 		}
 	}
 	_tmp21 = FALSE;
-	if (vala_code_context_get_directory (context) != NULL) {
+	_tmp22 = FALSE;
+	if (vala_code_context_get_legacy_headers (context)) {
+		_tmp22 = vala_code_context_get_directory (context) != NULL;
+	} else {
+		_tmp22 = FALSE;
+	}
+	if (_tmp22) {
 		_tmp21 = _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0;
 	} else {
 		_tmp21 = FALSE;
 	}
 	/* make sure include files can be found if -d is used */
 	if (_tmp21) {
+		char* _tmp25;
 		char* _tmp24;
 		char* _tmp23;
-		char* _tmp22;
+		_tmp25 = NULL;
 		_tmp24 = NULL;
 		_tmp23 = NULL;
-		_tmp22 = NULL;
-		cmdline = (_tmp24 = g_strconcat (cmdline, _tmp23 = (g_strconcat (" -I", _tmp22 = g_shell_quote (vala_code_context_get_directory (context)), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp24);
+		cmdline = (_tmp25 = g_strconcat (cmdline, _tmp24 = g_strconcat (" -I", _tmp23 = g_shell_quote (vala_code_context_get_directory (context)), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp25);
+		_tmp24 = (g_free (_tmp24), NULL);
 		_tmp23 = (g_free (_tmp23), NULL);
-		_tmp22 = (g_free (_tmp22), NULL);
 	}
 	/* we're only interested in non-pkg source files */
 	source_files = vala_code_context_get_source_files (context);
@@ -282,18 +289,18 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			ValaSourceFile* file;
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
+				char* _tmp29;
 				char* _tmp28;
 				char* _tmp27;
 				char* _tmp26;
-				char* _tmp25;
+				_tmp29 = NULL;
 				_tmp28 = NULL;
 				_tmp27 = NULL;
 				_tmp26 = NULL;
-				_tmp25 = NULL;
-				cmdline = (_tmp28 = g_strconcat (cmdline, _tmp27 = (g_strconcat (" ", _tmp26 = g_shell_quote (_tmp25 = vala_source_file_get_csource_filename (file)), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp28);
+				cmdline = (_tmp29 = g_strconcat (cmdline, _tmp28 = g_strconcat (" ", _tmp27 = g_shell_quote (_tmp26 = vala_source_file_get_csource_filename (file)), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp29);
+				_tmp28 = (g_free (_tmp28), NULL);
 				_tmp27 = (g_free (_tmp27), NULL);
 				_tmp26 = (g_free (_tmp26), NULL);
-				_tmp25 = (g_free (_tmp25), NULL);
 			}
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
 		}
@@ -305,26 +312,26 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		_file_it = gee_iterable_iterator ((GeeIterable*) c_source_files);
 		while (gee_iterator_next (_file_it)) {
 			char* file;
+			char* _tmp32;
 			char* _tmp31;
 			char* _tmp30;
-			char* _tmp29;
 			file = (char*) gee_iterator_get (_file_it);
+			_tmp32 = NULL;
 			_tmp31 = NULL;
 			_tmp30 = NULL;
-			_tmp29 = NULL;
-			cmdline = (_tmp31 = g_strconcat (cmdline, _tmp30 = (g_strconcat (" ", _tmp29 = g_shell_quote (file), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp31);
+			cmdline = (_tmp32 = g_strconcat (cmdline, _tmp31 = g_strconcat (" ", _tmp30 = g_shell_quote (file), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp32);
+			_tmp31 = (g_free (_tmp31), NULL);
 			_tmp30 = (g_free (_tmp30), NULL);
-			_tmp29 = (g_free (_tmp29), NULL);
 			file = (g_free (file), NULL);
 		}
 		(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 	}
 	/* add libraries after source files to fix linking
 	 with --as-needed and on Windows*/
+	_tmp34 = NULL;
 	_tmp33 = NULL;
-	_tmp32 = NULL;
-	cmdline = (_tmp33 = g_strconcat (cmdline, _tmp32 = (g_strconcat (" ", g_strstrip (pkgflags), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp33);
-	_tmp32 = (g_free (_tmp32), NULL);
+	cmdline = (_tmp34 = g_strconcat (cmdline, _tmp33 = g_strconcat (" ", g_strstrip (pkgflags), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp34);
+	_tmp33 = (g_free (_tmp33), NULL);
 	{
 		char** cc_option_collection;
 		int cc_option_collection_length1;
@@ -332,20 +339,20 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		cc_option_collection = cc_options;
 		cc_option_collection_length1 = cc_options_length1;
 		for (cc_option_it = 0; cc_option_it < cc_options_length1; cc_option_it = cc_option_it + 1) {
-			const char* _tmp37;
+			const char* _tmp38;
 			char* cc_option;
-			_tmp37 = NULL;
-			cc_option = (_tmp37 = cc_option_collection[cc_option_it], (_tmp37 == NULL) ? NULL : g_strdup (_tmp37));
+			_tmp38 = NULL;
+			cc_option = (_tmp38 = cc_option_collection[cc_option_it], (_tmp38 == NULL) ? NULL : g_strdup (_tmp38));
 			{
+				char* _tmp37;
 				char* _tmp36;
 				char* _tmp35;
-				char* _tmp34;
+				_tmp37 = NULL;
 				_tmp36 = NULL;
 				_tmp35 = NULL;
-				_tmp34 = NULL;
-				cmdline = (_tmp36 = g_strconcat (cmdline, _tmp35 = (g_strconcat (" ", _tmp34 = g_shell_quote (cc_option), NULL)), NULL), cmdline = (g_free (cmdline), NULL), _tmp36);
+				cmdline = (_tmp37 = g_strconcat (cmdline, _tmp36 = g_strconcat (" ", _tmp35 = g_shell_quote (cc_option), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp37);
+				_tmp36 = (g_free (_tmp36), NULL);
 				_tmp35 = (g_free (_tmp35), NULL);
-				_tmp34 = (g_free (_tmp34), NULL);
 				cc_option = (g_free (cc_option), NULL);
 			}
 		}
@@ -359,10 +366,10 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			goto __finally2;
 		}
 		if (exit_status != 0) {
-			char* _tmp38;
-			_tmp38 = NULL;
-			vala_report_error (NULL, _tmp38 = g_strdup_printf ("cc exited with status %d", exit_status));
-			_tmp38 = (g_free (_tmp38), NULL);
+			char* _tmp39;
+			_tmp39 = NULL;
+			vala_report_error (NULL, _tmp39 = g_strdup_printf ("cc exited with status %d", exit_status));
+			_tmp39 = (g_free (_tmp39), NULL);
 		}
 	}
 	goto __finally2;
@@ -398,18 +405,25 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			/* remove generated C source and header files */
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
+				gboolean _tmp41;
 				if (!vala_code_context_get_save_csources (context)) {
-					char* _tmp39;
-					_tmp39 = NULL;
-					g_unlink (_tmp39 = vala_source_file_get_csource_filename (file));
-					_tmp39 = (g_free (_tmp39), NULL);
-				}
-				if (!vala_code_context_get_save_cheaders (context)) {
 					char* _tmp40;
 					_tmp40 = NULL;
-					g_unlink (_tmp40 = vala_source_file_get_cheader_filename (file));
+					g_unlink (_tmp40 = vala_source_file_get_csource_filename (file));
 					_tmp40 = (g_free (_tmp40), NULL);
 				}
+				_tmp41 = FALSE;
+				if (vala_code_context_get_legacy_headers (context)) {
+					_tmp41 = !vala_code_context_get_save_cheaders (context);
+				} else {
+					_tmp41 = FALSE;
+				}
+				if (_tmp41) {
+					char* _tmp42;
+					_tmp42 = NULL;
+					g_unlink (_tmp42 = vala_source_file_get_cheader_filename (file));
+					_tmp42 = (g_free (_tmp42), NULL);
+				}
 			}
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
 		}
