@@ -1,6 +1,7 @@
 /* valaccodegenerator.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -62,6 +63,7 @@ static void vala_ccode_generator_real_visit_expression_statement (ValaCodeVisito
 static void vala_ccode_generator_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt);
 static void vala_ccode_generator_real_visit_switch_statement (ValaCodeVisitor* base, ValaSwitchStatement* stmt);
 static void vala_ccode_generator_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section);
+static void vala_ccode_generator_real_visit_switch_label (ValaCodeVisitor* base, ValaSwitchLabel* label);
 static void vala_ccode_generator_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt);
 static void vala_ccode_generator_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt);
 static void vala_ccode_generator_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt);
@@ -83,9 +85,8 @@ static void vala_ccode_generator_real_visit_integer_literal (ValaCodeVisitor* ba
 static void vala_ccode_generator_real_visit_real_literal (ValaCodeVisitor* base, ValaRealLiteral* expr);
 static void vala_ccode_generator_real_visit_string_literal (ValaCodeVisitor* base, ValaStringLiteral* expr);
 static void vala_ccode_generator_real_visit_null_literal (ValaCodeVisitor* base, ValaNullLiteral* expr);
-static void vala_ccode_generator_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr);
 static void vala_ccode_generator_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr);
-static void vala_ccode_generator_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr);
+static void vala_ccode_generator_real_visit_method_call (ValaCodeVisitor* base, ValaMethodCall* expr);
 static void vala_ccode_generator_real_visit_element_access (ValaCodeVisitor* base, ValaElementAccess* expr);
 static void vala_ccode_generator_real_visit_base_access (ValaCodeVisitor* base, ValaBaseAccess* expr);
 static void vala_ccode_generator_real_visit_postfix_expression (ValaCodeVisitor* base, ValaPostfixExpression* expr);
@@ -99,7 +100,6 @@ static void vala_ccode_generator_real_visit_addressof_expression (ValaCodeVisito
 static void vala_ccode_generator_real_visit_reference_transfer_expression (ValaCodeVisitor* base, ValaReferenceTransferExpression* expr);
 static void vala_ccode_generator_real_visit_binary_expression (ValaCodeVisitor* base, ValaBinaryExpression* expr);
 static void vala_ccode_generator_real_visit_type_check (ValaCodeVisitor* base, ValaTypeCheck* expr);
-static void vala_ccode_generator_real_visit_conditional_expression (ValaCodeVisitor* base, ValaConditionalExpression* expr);
 static void vala_ccode_generator_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l);
 static void vala_ccode_generator_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a);
 static gpointer vala_ccode_generator_parent_class = NULL;
@@ -110,18 +110,17 @@ static void vala_ccode_generator_finalize (ValaCodeVisitor* obj);
 ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type) {
 	ValaCCodeGenerator* self;
 	ValaCCodeModule* _tmp0;
-	self = ((ValaCCodeGenerator*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeGenerator*) g_type_create_instance (object_type);
 	/* included by inheritance
 	head = new CCodeBaseModule (this, head);
 	head = new CCodeStructModule (this, head);
 	head = new CCodeMethodModule (this, head);
+	head = new CCodeControlFlowModule (this, head);
 	head = new CCodeMemberAccessModule (this, head);
 	head = new CCodeAssignmentModule (this, head);
-	head = new CCodeInvocationExpressionModule (this, head);
+	head = new CCodeMethodCallModule (this, head);
 	head = new CCodeArrayModule (this, head);
 	head = new CCodeDelegateModule (this, head);
-	head = new CCodeDynamicPropertyModule (this, head);
-	head = new CCodeDynamicSignalModule (this, head);
 	head = new GErrorModule (this, head);
 	head = new GTypeModule (this, head);
 	head = new GObjectModule (this, head);
@@ -130,7 +129,7 @@ ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type) {
 	head = new DBusClientModule (this, head);
 	*/
 	_tmp0 = NULL;
-	self->head = (_tmp0 = ((ValaCCodeModule*) (vala_dbus_server_module_new (self, self->head))), (self->head == NULL ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL))), _tmp0);
+	self->head = (_tmp0 = (ValaCCodeModule*) vala_dbus_server_module_new (self, self->head), (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp0);
 	return self;
 }
 
@@ -142,7 +141,7 @@ ValaCCodeGenerator* vala_ccode_generator_new (void) {
 
 static void vala_ccode_generator_real_emit (ValaCodeGenerator* base, ValaCodeContext* context) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (context != NULL);
 	vala_ccode_module_emit (self->head, context);
 }
@@ -150,7 +149,7 @@ static void vala_ccode_generator_real_emit (ValaCodeGenerator* base, ValaCodeCon
 
 static void vala_ccode_generator_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (source_file != NULL);
 	vala_ccode_module_visit_source_file (self->head, source_file);
 }
@@ -158,7 +157,7 @@ static void vala_ccode_generator_real_visit_source_file (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (cl != NULL);
 	vala_ccode_module_visit_class (self->head, cl);
 }
@@ -166,7 +165,7 @@ static void vala_ccode_generator_real_visit_class (ValaCodeVisitor* base, ValaCl
 
 static void vala_ccode_generator_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (iface != NULL);
 	vala_ccode_module_visit_interface (self->head, iface);
 }
@@ -174,7 +173,7 @@ static void vala_ccode_generator_real_visit_interface (ValaCodeVisitor* base, Va
 
 static void vala_ccode_generator_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (st != NULL);
 	vala_ccode_module_visit_struct (self->head, st);
 }
@@ -182,7 +181,7 @@ static void vala_ccode_generator_real_visit_struct (ValaCodeVisitor* base, ValaS
 
 static void vala_ccode_generator_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (en != NULL);
 	vala_ccode_module_visit_enum (self->head, en);
 }
@@ -190,7 +189,7 @@ static void vala_ccode_generator_real_visit_enum (ValaCodeVisitor* base, ValaEnu
 
 static void vala_ccode_generator_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (ev != NULL);
 	vala_ccode_module_visit_enum_value (self->head, ev);
 }
@@ -198,7 +197,7 @@ static void vala_ccode_generator_real_visit_enum_value (ValaCodeVisitor* base, V
 
 static void vala_ccode_generator_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (edomain != NULL);
 	vala_ccode_module_visit_error_domain (self->head, edomain);
 }
@@ -206,7 +205,7 @@ static void vala_ccode_generator_real_visit_error_domain (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_error_code (ValaCodeVisitor* base, ValaErrorCode* ecode) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (ecode != NULL);
 	vala_ccode_module_visit_error_code (self->head, ecode);
 }
@@ -214,7 +213,7 @@ static void vala_ccode_generator_real_visit_error_code (ValaCodeVisitor* base, V
 
 static void vala_ccode_generator_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* d) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (d != NULL);
 	vala_ccode_module_visit_delegate (self->head, d);
 }
@@ -222,7 +221,7 @@ static void vala_ccode_generator_real_visit_delegate (ValaCodeVisitor* base, Val
 
 static void vala_ccode_generator_real_visit_member (ValaCodeVisitor* base, ValaMember* m) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (m != NULL);
 	vala_ccode_module_visit_member (self->head, m);
 }
@@ -230,7 +229,7 @@ static void vala_ccode_generator_real_visit_member (ValaCodeVisitor* base, ValaM
 
 static void vala_ccode_generator_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (c != NULL);
 	vala_ccode_module_visit_constant (self->head, c);
 }
@@ -238,7 +237,7 @@ static void vala_ccode_generator_real_visit_constant (ValaCodeVisitor* base, Val
 
 static void vala_ccode_generator_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (f != NULL);
 	vala_ccode_module_visit_field (self->head, f);
 }
@@ -246,7 +245,7 @@ static void vala_ccode_generator_real_visit_field (ValaCodeVisitor* base, ValaFi
 
 static void vala_ccode_generator_real_visit_method (ValaCodeVisitor* base, ValaMethod* m) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (m != NULL);
 	vala_ccode_module_visit_method (self->head, m);
 }
@@ -254,7 +253,7 @@ static void vala_ccode_generator_real_visit_method (ValaCodeVisitor* base, ValaM
 
 static void vala_ccode_generator_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (m != NULL);
 	vala_ccode_module_visit_creation_method (self->head, m);
 }
@@ -262,7 +261,7 @@ static void vala_ccode_generator_real_visit_creation_method (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (p != NULL);
 	vala_ccode_module_visit_formal_parameter (self->head, p);
 }
@@ -270,7 +269,7 @@ static void vala_ccode_generator_real_visit_formal_parameter (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (prop != NULL);
 	vala_ccode_module_visit_property (self->head, prop);
 }
@@ -278,7 +277,7 @@ static void vala_ccode_generator_real_visit_property (ValaCodeVisitor* base, Val
 
 static void vala_ccode_generator_real_visit_property_accessor (ValaCodeVisitor* base, ValaPropertyAccessor* acc) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (acc != NULL);
 	vala_ccode_module_visit_property_accessor (self->head, acc);
 }
@@ -286,7 +285,7 @@ static void vala_ccode_generator_real_visit_property_accessor (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (sig != NULL);
 	vala_ccode_module_visit_signal (self->head, sig);
 }
@@ -294,7 +293,7 @@ static void vala_ccode_generator_real_visit_signal (ValaCodeVisitor* base, ValaS
 
 static void vala_ccode_generator_real_visit_constructor (ValaCodeVisitor* base, ValaConstructor* c) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (c != NULL);
 	vala_ccode_module_visit_constructor (self->head, c);
 }
@@ -302,7 +301,7 @@ static void vala_ccode_generator_real_visit_constructor (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (d != NULL);
 	vala_ccode_module_visit_destructor (self->head, d);
 }
@@ -310,7 +309,7 @@ static void vala_ccode_generator_real_visit_destructor (ValaCodeVisitor* base, V
 
 static void vala_ccode_generator_real_visit_block (ValaCodeVisitor* base, ValaBlock* b) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (b != NULL);
 	vala_ccode_module_visit_block (self->head, b);
 }
@@ -318,7 +317,7 @@ static void vala_ccode_generator_real_visit_block (ValaCodeVisitor* base, ValaBl
 
 static void vala_ccode_generator_real_visit_empty_statement (ValaCodeVisitor* base, ValaEmptyStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_empty_statement (self->head, stmt);
 }
@@ -326,7 +325,7 @@ static void vala_ccode_generator_real_visit_empty_statement (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_declaration_statement (ValaCodeVisitor* base, ValaDeclarationStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_declaration_statement (self->head, stmt);
 }
@@ -334,7 +333,7 @@ static void vala_ccode_generator_real_visit_declaration_statement (ValaCodeVisit
 
 static void vala_ccode_generator_real_visit_local_variable (ValaCodeVisitor* base, ValaLocalVariable* local) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (local != NULL);
 	vala_ccode_module_visit_local_variable (self->head, local);
 }
@@ -342,7 +341,7 @@ static void vala_ccode_generator_real_visit_local_variable (ValaCodeVisitor* bas
 
 static void vala_ccode_generator_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (list != NULL);
 	vala_ccode_module_visit_initializer_list (self->head, list);
 }
@@ -350,7 +349,7 @@ static void vala_ccode_generator_real_visit_initializer_list (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_end_full_expression (ValaCodeVisitor* base, ValaExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_end_full_expression (self->head, expr);
 }
@@ -358,7 +357,7 @@ static void vala_ccode_generator_real_visit_end_full_expression (ValaCodeVisitor
 
 static void vala_ccode_generator_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_expression_statement (self->head, stmt);
 }
@@ -366,7 +365,7 @@ static void vala_ccode_generator_real_visit_expression_statement (ValaCodeVisito
 
 static void vala_ccode_generator_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_if_statement (self->head, stmt);
 }
@@ -374,7 +373,7 @@ static void vala_ccode_generator_real_visit_if_statement (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_switch_statement (ValaCodeVisitor* base, ValaSwitchStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_switch_statement (self->head, stmt);
 }
@@ -382,15 +381,23 @@ static void vala_ccode_generator_real_visit_switch_statement (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (section != NULL);
 	vala_ccode_module_visit_switch_section (self->head, section);
 }
 
 
+static void vala_ccode_generator_real_visit_switch_label (ValaCodeVisitor* base, ValaSwitchLabel* label) {
+	ValaCCodeGenerator * self;
+	self = (ValaCCodeGenerator*) base;
+	g_return_if_fail (label != NULL);
+	vala_ccode_module_visit_switch_label (self->head, label);
+}
+
+
 static void vala_ccode_generator_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_while_statement (self->head, stmt);
 }
@@ -398,7 +405,7 @@ static void vala_ccode_generator_real_visit_while_statement (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_do_statement (self->head, stmt);
 }
@@ -406,7 +413,7 @@ static void vala_ccode_generator_real_visit_do_statement (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_for_statement (self->head, stmt);
 }
@@ -414,7 +421,7 @@ static void vala_ccode_generator_real_visit_for_statement (ValaCodeVisitor* base
 
 static void vala_ccode_generator_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_foreach_statement (self->head, stmt);
 }
@@ -422,7 +429,7 @@ static void vala_ccode_generator_real_visit_foreach_statement (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_break_statement (ValaCodeVisitor* base, ValaBreakStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_break_statement (self->head, stmt);
 }
@@ -430,7 +437,7 @@ static void vala_ccode_generator_real_visit_break_statement (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_continue_statement (ValaCodeVisitor* base, ValaContinueStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_continue_statement (self->head, stmt);
 }
@@ -438,7 +445,7 @@ static void vala_ccode_generator_real_visit_continue_statement (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_return_statement (self->head, stmt);
 }
@@ -446,7 +453,7 @@ static void vala_ccode_generator_real_visit_return_statement (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_yield_statement (ValaCodeVisitor* base, ValaYieldStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_yield_statement (self->head, stmt);
 }
@@ -454,7 +461,7 @@ static void vala_ccode_generator_real_visit_yield_statement (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_throw_statement (self->head, stmt);
 }
@@ -462,7 +469,7 @@ static void vala_ccode_generator_real_visit_throw_statement (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_try_statement (self->head, stmt);
 }
@@ -470,7 +477,7 @@ static void vala_ccode_generator_real_visit_try_statement (ValaCodeVisitor* base
 
 static void vala_ccode_generator_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (clause != NULL);
 	vala_ccode_module_visit_catch_clause (self->head, clause);
 }
@@ -478,7 +485,7 @@ static void vala_ccode_generator_real_visit_catch_clause (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_lock_statement (ValaCodeVisitor* base, ValaLockStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_lock_statement (self->head, stmt);
 }
@@ -486,7 +493,7 @@ static void vala_ccode_generator_real_visit_lock_statement (ValaCodeVisitor* bas
 
 static void vala_ccode_generator_real_visit_delete_statement (ValaCodeVisitor* base, ValaDeleteStatement* stmt) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (stmt != NULL);
 	vala_ccode_module_visit_delete_statement (self->head, stmt);
 }
@@ -494,7 +501,7 @@ static void vala_ccode_generator_real_visit_delete_statement (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_expression (ValaCodeVisitor* base, ValaExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_expression (self->head, expr);
 }
@@ -502,7 +509,7 @@ static void vala_ccode_generator_real_visit_expression (ValaCodeVisitor* base, V
 
 static void vala_ccode_generator_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_array_creation_expression (self->head, expr);
 }
@@ -510,7 +517,7 @@ static void vala_ccode_generator_real_visit_array_creation_expression (ValaCodeV
 
 static void vala_ccode_generator_real_visit_boolean_literal (ValaCodeVisitor* base, ValaBooleanLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_boolean_literal (self->head, expr);
 }
@@ -518,7 +525,7 @@ static void vala_ccode_generator_real_visit_boolean_literal (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_character_literal (ValaCodeVisitor* base, ValaCharacterLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_character_literal (self->head, expr);
 }
@@ -526,7 +533,7 @@ static void vala_ccode_generator_real_visit_character_literal (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_integer_literal (ValaCodeVisitor* base, ValaIntegerLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_integer_literal (self->head, expr);
 }
@@ -534,7 +541,7 @@ static void vala_ccode_generator_real_visit_integer_literal (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_real_literal (ValaCodeVisitor* base, ValaRealLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_real_literal (self->head, expr);
 }
@@ -542,7 +549,7 @@ static void vala_ccode_generator_real_visit_real_literal (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_string_literal (ValaCodeVisitor* base, ValaStringLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_string_literal (self->head, expr);
 }
@@ -550,39 +557,31 @@ static void vala_ccode_generator_real_visit_string_literal (ValaCodeVisitor* bas
 
 static void vala_ccode_generator_real_visit_null_literal (ValaCodeVisitor* base, ValaNullLiteral* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_null_literal (self->head, expr);
 }
 
 
-static void vala_ccode_generator_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
-	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
-	g_return_if_fail (expr != NULL);
-	vala_ccode_module_visit_parenthesized_expression (self->head, expr);
-}
-
-
 static void vala_ccode_generator_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_member_access (self->head, expr);
 }
 
 
-static void vala_ccode_generator_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr) {
+static void vala_ccode_generator_real_visit_method_call (ValaCodeVisitor* base, ValaMethodCall* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
-	vala_ccode_module_visit_invocation_expression (self->head, expr);
+	vala_ccode_module_visit_method_call (self->head, expr);
 }
 
 
 static void vala_ccode_generator_real_visit_element_access (ValaCodeVisitor* base, ValaElementAccess* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_element_access (self->head, expr);
 }
@@ -590,7 +589,7 @@ static void vala_ccode_generator_real_visit_element_access (ValaCodeVisitor* bas
 
 static void vala_ccode_generator_real_visit_base_access (ValaCodeVisitor* base, ValaBaseAccess* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_base_access (self->head, expr);
 }
@@ -598,7 +597,7 @@ static void vala_ccode_generator_real_visit_base_access (ValaCodeVisitor* base,
 
 static void vala_ccode_generator_real_visit_postfix_expression (ValaCodeVisitor* base, ValaPostfixExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_postfix_expression (self->head, expr);
 }
@@ -606,7 +605,7 @@ static void vala_ccode_generator_real_visit_postfix_expression (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_object_creation_expression (self->head, expr);
 }
@@ -614,7 +613,7 @@ static void vala_ccode_generator_real_visit_object_creation_expression (ValaCode
 
 static void vala_ccode_generator_real_visit_sizeof_expression (ValaCodeVisitor* base, ValaSizeofExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_sizeof_expression (self->head, expr);
 }
@@ -622,7 +621,7 @@ static void vala_ccode_generator_real_visit_sizeof_expression (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_typeof_expression (ValaCodeVisitor* base, ValaTypeofExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_typeof_expression (self->head, expr);
 }
@@ -630,7 +629,7 @@ static void vala_ccode_generator_real_visit_typeof_expression (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_unary_expression (ValaCodeVisitor* base, ValaUnaryExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_unary_expression (self->head, expr);
 }
@@ -638,7 +637,7 @@ static void vala_ccode_generator_real_visit_unary_expression (ValaCodeVisitor* b
 
 static void vala_ccode_generator_real_visit_cast_expression (ValaCodeVisitor* base, ValaCastExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_cast_expression (self->head, expr);
 }
@@ -646,7 +645,7 @@ static void vala_ccode_generator_real_visit_cast_expression (ValaCodeVisitor* ba
 
 static void vala_ccode_generator_real_visit_pointer_indirection (ValaCodeVisitor* base, ValaPointerIndirection* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_pointer_indirection (self->head, expr);
 }
@@ -654,7 +653,7 @@ static void vala_ccode_generator_real_visit_pointer_indirection (ValaCodeVisitor
 
 static void vala_ccode_generator_real_visit_addressof_expression (ValaCodeVisitor* base, ValaAddressofExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_addressof_expression (self->head, expr);
 }
@@ -662,7 +661,7 @@ static void vala_ccode_generator_real_visit_addressof_expression (ValaCodeVisito
 
 static void vala_ccode_generator_real_visit_reference_transfer_expression (ValaCodeVisitor* base, ValaReferenceTransferExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_reference_transfer_expression (self->head, expr);
 }
@@ -670,7 +669,7 @@ static void vala_ccode_generator_real_visit_reference_transfer_expression (ValaC
 
 static void vala_ccode_generator_real_visit_binary_expression (ValaCodeVisitor* base, ValaBinaryExpression* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_binary_expression (self->head, expr);
 }
@@ -678,23 +677,15 @@ static void vala_ccode_generator_real_visit_binary_expression (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_type_check (ValaCodeVisitor* base, ValaTypeCheck* expr) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (expr != NULL);
 	vala_ccode_module_visit_type_check (self->head, expr);
 }
 
 
-static void vala_ccode_generator_real_visit_conditional_expression (ValaCodeVisitor* base, ValaConditionalExpression* expr) {
-	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
-	g_return_if_fail (expr != NULL);
-	vala_ccode_module_visit_conditional_expression (self->head, expr);
-}
-
-
 static void vala_ccode_generator_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (l != NULL);
 	vala_ccode_module_visit_lambda_expression (self->head, l);
 }
@@ -702,7 +693,7 @@ static void vala_ccode_generator_real_visit_lambda_expression (ValaCodeVisitor*
 
 static void vala_ccode_generator_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a) {
 	ValaCCodeGenerator * self;
-	self = ((ValaCCodeGenerator*) (base));
+	self = (ValaCCodeGenerator*) base;
 	g_return_if_fail (a != NULL);
 	vala_ccode_module_visit_assignment (self->head, a);
 }
@@ -742,6 +733,7 @@ static void vala_ccode_generator_class_init (ValaCCodeGeneratorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_ccode_generator_real_visit_if_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_statement = vala_ccode_generator_real_visit_switch_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_section = vala_ccode_generator_real_visit_switch_section;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_label = vala_ccode_generator_real_visit_switch_label;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_while_statement = vala_ccode_generator_real_visit_while_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_do_statement = vala_ccode_generator_real_visit_do_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_for_statement = vala_ccode_generator_real_visit_for_statement;
@@ -763,9 +755,8 @@ static void vala_ccode_generator_class_init (ValaCCodeGeneratorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_real_literal = vala_ccode_generator_real_visit_real_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_string_literal = vala_ccode_generator_real_visit_string_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_null_literal = vala_ccode_generator_real_visit_null_literal;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_ccode_generator_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_ccode_generator_real_visit_member_access;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_invocation_expression = vala_ccode_generator_real_visit_invocation_expression;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_method_call = vala_ccode_generator_real_visit_method_call;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_element_access = vala_ccode_generator_real_visit_element_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_base_access = vala_ccode_generator_real_visit_base_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_postfix_expression = vala_ccode_generator_real_visit_postfix_expression;
@@ -779,7 +770,6 @@ static void vala_ccode_generator_class_init (ValaCCodeGeneratorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_reference_transfer_expression = vala_ccode_generator_real_visit_reference_transfer_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_binary_expression = vala_ccode_generator_real_visit_binary_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_type_check = vala_ccode_generator_real_visit_type_check;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_conditional_expression = vala_ccode_generator_real_visit_conditional_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_lambda_expression = vala_ccode_generator_real_visit_lambda_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_assignment = vala_ccode_generator_real_visit_assignment;
 }
@@ -792,7 +782,7 @@ static void vala_ccode_generator_instance_init (ValaCCodeGenerator * self) {
 static void vala_ccode_generator_finalize (ValaCodeVisitor* obj) {
 	ValaCCodeGenerator * self;
 	self = VALA_CCODE_GENERATOR (obj);
-	(self->head == NULL ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)));
+	(self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL));
 	VALA_CODE_VISITOR_CLASS (vala_ccode_generator_parent_class)->finalize (obj);
 }
 
