@@ -69,6 +69,7 @@
 #include <gee/collection.h>
 #include <vala/valastatement.h>
 #include <gobject/valaccodebasemodule.h>
+#include <gobject/valaccodedeclarationspace.h>
 #include <gobject/valaccodemethodmodule.h>
 #include <gobject/valagerrormodule.h>
 
@@ -630,8 +631,8 @@ static void vala_gasync_module_append_struct (ValaGAsyncModule* self, ValaCCodeS
 	_tmp2 = NULL;
 	_tmp3 = NULL;
 	typedef_ = (_tmp3 = vala_ccode_type_definition_new (_tmp2 = g_strconcat ("struct ", vala_ccode_struct_get_name (structure), NULL), (ValaCCodeDeclarator*) typename), _tmp2 = (g_free (_tmp2), NULL), _tmp3);
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_declaration, (ValaCCodeNode*) typedef_);
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_definition, (ValaCCodeNode*) structure);
+	vala_ccode_declaration_space_add_type_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) typedef_);
+	vala_ccode_declaration_space_add_type_definition (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) structure);
 	(typename == NULL) ? NULL : (typename = (vala_ccode_node_unref (typename), NULL));
 	(typedef_ == NULL) ? NULL : (typedef_ = (vala_ccode_node_unref (typedef_), NULL));
 }
@@ -648,12 +649,12 @@ static void vala_gasync_module_append_function (ValaGAsyncModule* self, ValaCCod
 	if ((vala_ccode_function_get_modifiers (function) & VALA_CCODE_MODIFIERS_STATIC) != 0) {
 		ValaCCodeFunction* _tmp1;
 		_tmp1 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp1 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp1 = vala_ccode_function_copy (function)));
 		(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL));
 	} else {
 		ValaCCodeFunction* _tmp2;
 		_tmp2 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp2 = vala_ccode_function_copy (function)));
+		vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp2 = vala_ccode_function_copy (function)));
 		(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_ccode_node_unref (_tmp2), NULL));
 	}
 	vala_ccode_function_set_block (function, block);
@@ -844,7 +845,7 @@ static ValaCCodeFunction* vala_gasync_module_generate_ready_function (ValaGAsync
 	(_tmp26 == NULL) ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL));
 	vala_ccode_function_set_modifiers (readyfunc, vala_ccode_function_get_modifiers (readyfunc) | VALA_CCODE_MODIFIERS_STATIC);
 	_tmp27 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_declaration, (ValaCCodeNode*) (_tmp27 = vala_ccode_function_copy (readyfunc)));
+	vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->source_declarations, (ValaCCodeNode*) (_tmp27 = vala_ccode_function_copy (readyfunc)));
 	(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL));
 	vala_ccode_function_set_block (readyfunc, readyblock);
 	_tmp28 = NULL;
