@@ -44,9 +44,9 @@ static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NU
  */
 ValaBreakStatement* vala_break_statement_construct (GType object_type, ValaSourceReference* source) {
 	ValaBreakStatement* self;
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = ((ValaBreakStatement*) (g_type_create_instance (object_type)));
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	g_return_val_if_fail (source != NULL, NULL);
+	self = (ValaBreakStatement*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -58,8 +58,8 @@ ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
 
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBreakStatement * self;
-	self = VALA_BREAK_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaBreakStatement*) base;
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_break_statement (visitor, self);
 }
 
