@@ -1,6 +1,6 @@
 /* valacodecontext.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/list.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -41,22 +41,33 @@ G_BEGIN_DECLS
 #define VALA_CODE_CONTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_CONTEXT, ValaCodeContextClass))
 
 typedef struct _ValaCodeContextPrivate ValaCodeContextPrivate;
+typedef struct _ValaParamSpecCodeContext ValaParamSpecCodeContext;
 
 /**
  * The root of the code tree.
  */
 struct _ValaCodeContext {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeContextPrivate * priv;
 };
 
 struct _ValaCodeContextClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeContext *self);
+};
+
+struct _ValaParamSpecCodeContext {
+	GParamSpec parent_instance;
 };
 
 
 gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor);
+ValaCodeContext* vala_code_context_construct (GType object_type);
 ValaCodeContext* vala_code_context_new (void);
+ValaCodeContext* vala_code_context_get (void);
+void vala_code_context_push (ValaCodeContext* context);
+void vala_code_context_pop (void);
 GeeList* vala_code_context_get_source_files (ValaCodeContext* self);
 GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self);
 void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* file);
@@ -66,9 +77,7 @@ gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg);
 void vala_code_context_add_package (ValaCodeContext* self, const char* pkg);
 void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor);
 void vala_code_context_find_header_cycles (ValaCodeContext* self);
-void vala_code_context_add_define (ValaCodeContext* self, const char* define);
-gboolean vala_code_context_ignore_node (ValaCodeContext* self, ValaCodeNode* node);
-char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg, int vapi_directories_length1, char** vapi_directories);
+char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg, char** vapi_directories, int vapi_directories_length1);
 const char* vala_code_context_get_library (ValaCodeContext* self);
 void vala_code_context_set_library (ValaCodeContext* self, const char* value);
 gboolean vala_code_context_get_memory_management (ValaCodeContext* self);
@@ -77,12 +86,18 @@ gboolean vala_code_context_get_assert (ValaCodeContext* self);
 void vala_code_context_set_assert (ValaCodeContext* self, gboolean value);
 gboolean vala_code_context_get_checking (ValaCodeContext* self);
 void vala_code_context_set_checking (ValaCodeContext* self, gboolean value);
-gboolean vala_code_context_get_non_null (ValaCodeContext* self);
-void vala_code_context_set_non_null (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_deprecated (ValaCodeContext* self);
+void vala_code_context_set_deprecated (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_experimental (ValaCodeContext* self);
+void vala_code_context_set_experimental (ValaCodeContext* self, gboolean value);
 gboolean vala_code_context_get_non_null_experimental (ValaCodeContext* self);
 void vala_code_context_set_non_null_experimental (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_dbus_transformation (ValaCodeContext* self);
+void vala_code_context_set_dbus_transformation (ValaCodeContext* self, gboolean value);
 gboolean vala_code_context_get_ccode_only (ValaCodeContext* self);
 void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value);
+const char* vala_code_context_get_header_filename (ValaCodeContext* self);
+void vala_code_context_set_header_filename (ValaCodeContext* self, const char* value);
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self);
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value);
 const char* vala_code_context_get_output (ValaCodeContext* self);
@@ -91,6 +106,7 @@ const char* vala_code_context_get_basedir (ValaCodeContext* self);
 void vala_code_context_set_basedir (ValaCodeContext* self, const char* value);
 const char* vala_code_context_get_directory (ValaCodeContext* self);
 void vala_code_context_set_directory (ValaCodeContext* self, const char* value);
+gboolean vala_code_context_get_legacy_headers (ValaCodeContext* self);
 gboolean vala_code_context_get_debug (ValaCodeContext* self);
 void vala_code_context_set_debug (ValaCodeContext* self, gboolean value);
 gint vala_code_context_get_optlevel (ValaCodeContext* self);
@@ -107,10 +123,17 @@ gint vala_code_context_get_target_glib_minor (ValaCodeContext* self);
 void vala_code_context_set_target_glib_minor (ValaCodeContext* self, gint value);
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self);
 gboolean vala_code_context_get_save_cheaders (ValaCodeContext* self);
+ValaReport* vala_code_context_get_report (ValaCodeContext* self);
+void vala_code_context_set_report (ValaCodeContext* self, ValaReport* value);
 ValaNamespace* vala_code_context_get_root (ValaCodeContext* self);
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self);
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value);
+GParamSpec* vala_param_spec_code_context (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_context (const GValue* value);
+void vala_value_set_code_context (GValue* value, gpointer v_object);
 GType vala_code_context_get_type (void);
+gpointer vala_code_context_ref (gpointer instance);
+void vala_code_context_unref (gpointer instance);
 
 
 G_END_DECLS
