@@ -1,6 +1,6 @@
 /* valainterface.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -90,6 +90,7 @@ static gboolean vala_interface_real_is_reference_type (ValaTypeSymbol* base);
 static gboolean vala_interface_real_is_reference_counting (ValaTypeSymbol* base);
 static char* vala_interface_real_get_ref_function (ValaTypeSymbol* base);
 static char* vala_interface_real_get_unref_function (ValaTypeSymbol* base);
+static char* vala_interface_real_get_ref_sink_function (ValaTypeSymbol* base);
 static gboolean vala_interface_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSymbol* t);
 static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAttribute* a);
 static char* vala_interface_real_get_marshaller_type_name (ValaTypeSymbol* base);
@@ -254,7 +255,7 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) vala_method_get_this_parameter (m)), (ValaSymbol*) vala_method_get_this_parameter (m));
 	}
 	_tmp2 = FALSE;
-	if (!(VALA_IS_VOID_TYPE (vala_method_get_return_type (m)))) {
+	if (!VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) {
 		GeeList* _tmp3;
 		_tmp3 = NULL;
 		_tmp2 = gee_collection_get_size ((GeeCollection*) (_tmp3 = vala_method_get_postconditions (m))) > 0;
@@ -441,6 +442,17 @@ static char* vala_interface_real_get_cname (ValaTypeSymbol* base, gboolean const
 }
 
 
+void vala_interface_set_cname (ValaInterface* self, const char* cname) {
+	char* _tmp1;
+	const char* _tmp0;
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (cname != NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+}
+
+
 /**
  * Returns the string to be prepended to the name of members of this
  * interface when used in C code.
@@ -746,6 +758,31 @@ static char* vala_interface_real_get_unref_function (ValaTypeSymbol* base) {
 }
 
 
+static char* vala_interface_real_get_ref_sink_function (ValaTypeSymbol* base) {
+	ValaInterface * self;
+	self = (ValaInterface*) base;
+	{
+		GeeIterator* _prerequisite_it;
+		_prerequisite_it = gee_iterable_iterator ((GeeIterable*) self->priv->prerequisites);
+		while (gee_iterator_next (_prerequisite_it)) {
+			ValaDataType* prerequisite;
+			char* ref_sink_func;
+			prerequisite = (ValaDataType*) gee_iterator_get (_prerequisite_it);
+			ref_sink_func = vala_typesymbol_get_ref_sink_function (vala_data_type_get_data_type (prerequisite));
+			if (ref_sink_func != NULL) {
+				char* _tmp0;
+				_tmp0 = NULL;
+				return (_tmp0 = ref_sink_func, (prerequisite == NULL) ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL)), (_prerequisite_it == NULL) ? NULL : (_prerequisite_it = (gee_collection_object_unref (_prerequisite_it), NULL)), _tmp0);
+			}
+			(prerequisite == NULL) ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL));
+			ref_sink_func = (g_free (ref_sink_func), NULL);
+		}
+		(_prerequisite_it == NULL) ? NULL : (_prerequisite_it = (gee_collection_object_unref (_prerequisite_it), NULL));
+	}
+	return NULL;
+}
+
+
 static gboolean vala_interface_real_is_subtype_of (ValaTypeSymbol* base, ValaTypeSymbol* t) {
 	ValaInterface * self;
 	self = (ValaInterface*) base;
@@ -929,8 +966,8 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) self->priv->prerequisites, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->prerequisites, i, new_type);
+			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (self->priv->prerequisites, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (self->priv->prerequisites, i, new_type);
 				return;
 			}
 		}
@@ -1068,7 +1105,7 @@ static gboolean vala_interface_real_check (ValaCodeNode* base, ValaSemanticAnaly
 				(class_or_interface == NULL) ? NULL : (class_or_interface = (vala_code_node_unref (class_or_interface), NULL));
 				continue;
 			}
-			if (!(VALA_IS_OBJECT_TYPE_SYMBOL (class_or_interface))) {
+			if (!VALA_IS_OBJECT_TYPE_SYMBOL (class_or_interface)) {
 				char* _tmp14;
 				char* _tmp13;
 				char* _tmp12;
@@ -1251,6 +1288,7 @@ static void vala_interface_class_init (ValaInterfaceClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->is_reference_counting = vala_interface_real_is_reference_counting;
 	VALA_TYPESYMBOL_CLASS (klass)->get_ref_function = vala_interface_real_get_ref_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_unref_function = vala_interface_real_get_unref_function;
+	VALA_TYPESYMBOL_CLASS (klass)->get_ref_sink_function = vala_interface_real_get_ref_sink_function;
 	VALA_TYPESYMBOL_CLASS (klass)->is_subtype_of = vala_interface_real_is_subtype_of;
 	VALA_TYPESYMBOL_CLASS (klass)->get_marshaller_type_name = vala_interface_real_get_marshaller_type_name;
 	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_interface_real_get_get_value_function;
