@@ -1,6 +1,6 @@
 /* valainterface.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,10 +25,10 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
-#include <vala/valatypesymbol.h>
+#include <vala/valaobjecttypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,42 +47,43 @@ typedef struct _ValaInterfacePrivate ValaInterfacePrivate;
  * Represents a class declaration in the source code.
  */
 struct _ValaInterface {
-	ValaTypesymbol parent_instance;
+	ValaObjectTypeSymbol parent_instance;
 	ValaInterfacePrivate * priv;
 };
+
 struct _ValaInterfaceClass {
-	ValaTypesymbolClass parent_class;
+	ValaObjectTypeSymbolClass parent_class;
 };
 
+
+GeeList* vala_interface_get_classes (ValaInterface* self);
+GeeList* vala_interface_get_structs (ValaInterface* self);
+GeeList* vala_interface_get_enums (ValaInterface* self);
+GeeList* vala_interface_get_delegates (ValaInterface* self);
+ValaInterface* vala_interface_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference);
-void vala_interface_add_type_parameter (ValaInterface* self, ValaTypeParameter* p);
-GeeCollection* vala_interface_get_type_parameters (ValaInterface* self);
 void vala_interface_add_prerequisite (ValaInterface* self, ValaDataType* type);
 void vala_interface_prepend_prerequisite (ValaInterface* self, ValaDataType* type);
-GeeCollection* vala_interface_get_prerequisites (ValaInterface* self);
+GeeList* vala_interface_get_prerequisites (ValaInterface* self);
 void vala_interface_add_method (ValaInterface* self, ValaMethod* m);
-GeeCollection* vala_interface_get_methods (ValaInterface* self);
 void vala_interface_add_field (ValaInterface* self, ValaField* f);
-GeeCollection* vala_interface_get_fields (ValaInterface* self);
+GeeList* vala_interface_get_fields (ValaInterface* self);
 void vala_interface_add_property (ValaInterface* self, ValaProperty* prop);
-GeeCollection* vala_interface_get_properties (ValaInterface* self);
 void vala_interface_add_signal (ValaInterface* self, ValaSignal* sig);
-GeeCollection* vala_interface_get_signals (ValaInterface* self);
 void vala_interface_add_class (ValaInterface* self, ValaClass* cl);
 void vala_interface_add_struct (ValaInterface* self, ValaStruct* st);
 void vala_interface_add_enum (ValaInterface* self, ValaEnum* en);
 void vala_interface_add_delegate (ValaInterface* self, ValaDelegate* d);
+void vala_interface_set_cname (ValaInterface* self, const char* cname);
 char* vala_interface_get_lower_case_csuffix (ValaInterface* self);
+char* vala_interface_get_default_lower_case_csuffix (ValaInterface* self);
 void vala_interface_set_lower_case_csuffix (ValaInterface* self, const char* csuffix);
 void vala_interface_process_attributes (ValaInterface* self);
 char* vala_interface_get_type_cname (ValaInterface* self);
 void vala_interface_set_type_cname (ValaInterface* self, const char* type_cname);
-gboolean vala_interface_get_is_static (ValaInterface* self);
-void vala_interface_set_is_static (ValaInterface* self, gboolean value);
-gboolean vala_interface_get_declaration_only (ValaInterface* self);
-void vala_interface_set_declaration_only (ValaInterface* self, gboolean value);
 GType vala_interface_get_type (void);
 
+
 G_END_DECLS
 
 #endif
