@@ -30,12 +30,13 @@
 #include <gee/iterator.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
+#include <vala/valasignal.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valascope.h>
 #include <vala/valaexpression.h>
 #include <vala/valalocalvariable.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valaattribute.h>
 #include <vala/valareport.h>
@@ -51,7 +52,6 @@
 #include <vala/valaobjecttypesymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valagenerictype.h>
-#include <vala/valasignal.h>
 #include <vala/valavoidtype.h>
 #include <vala/valaarraytype.h>
 #include <vala/valabasicblock.h>
@@ -78,6 +78,7 @@ struct _ValaMethodPrivate {
 	gboolean _array_null_terminated;
 	gboolean _printf_format;
 	gboolean _has_construct_function;
+	ValaSignal* _signal_reference;
 	gboolean _coroutine;
 	GeeList* parameters;
 	char* cname;
@@ -1801,6 +1802,18 @@ void vala_method_set_has_construct_function (ValaMethod* self, gboolean value) {
 }
 
 
+ValaSignal* vala_method_get_signal_reference (ValaMethod* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return self->priv->_signal_reference;
+}
+
+
+void vala_method_set_signal_reference (ValaMethod* self, ValaSignal* value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_signal_reference = value;
+}
+
+
 gboolean vala_method_get_coroutine (ValaMethod* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_coroutine;
