@@ -1,6 +1,6 @@
 /* valascanner.vala
  *
- * Copyright (C) 2008  Jürg Billeter
+ * Copyright (C) 2008-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -43,6 +43,7 @@ enum  {
 };
 static gboolean vala_scanner_is_ident_char (ValaScanner* self, gchar c);
 static ValaTokenType vala_scanner_get_identifier_or_keyword (ValaScanner* self, gchar* begin, gint len);
+static ValaTokenType vala_scanner_read_number (ValaScanner* self);
 static gboolean vala_scanner_matches (ValaScanner* self, gchar* begin, const char* keyword);
 static gboolean vala_scanner_whitespace (ValaScanner* self);
 static gboolean vala_scanner_comment (ValaScanner* self);
@@ -83,7 +84,7 @@ static gboolean vala_scanner_is_ident_char (ValaScanner* self, gchar c) {
 	} else {
 		_tmp0 = c == '_';
 	}
-	return (_tmp0);
+	return _tmp0;
 }
 
 
@@ -669,6 +670,226 @@ static ValaTokenType vala_scanner_get_identifier_or_keyword (ValaScanner* self,
 }
 
 
+static ValaTokenType vala_scanner_read_number (ValaScanner* self) {
+	ValaTokenType type;
+	gboolean _tmp0;
+	gboolean _tmp1;
+	gboolean _tmp2;
+	gboolean _tmp5;
+	gboolean _tmp6;
+	gboolean _tmp8;
+	g_return_val_if_fail (self != NULL, 0);
+	type = VALA_TOKEN_TYPE_INTEGER_LITERAL;
+	_tmp0 = FALSE;
+	_tmp1 = FALSE;
+	_tmp2 = FALSE;
+	if (self->priv->current < (self->priv->end - 2)) {
+		_tmp2 = self->priv->current[0] == '0';
+	} else {
+		_tmp2 = FALSE;
+	}
+	if (_tmp2) {
+		_tmp1 = self->priv->current[1] == 'x';
+	} else {
+		_tmp1 = FALSE;
+	}
+	if (_tmp1) {
+		_tmp0 = g_ascii_isxdigit (self->priv->current[2]);
+	} else {
+		_tmp0 = FALSE;
+	}
+	/* integer part*/
+	if (_tmp0) {
+		/* hexadecimal integer literal*/
+		self->priv->current = self->priv->current + 2;
+		while (TRUE) {
+			gboolean _tmp3;
+			_tmp3 = FALSE;
+			if (self->priv->current < self->priv->end) {
+				_tmp3 = g_ascii_isxdigit (self->priv->current[0]);
+			} else {
+				_tmp3 = FALSE;
+			}
+			if (!_tmp3) {
+				break;
+			}
+			self->priv->current++;
+		}
+	} else {
+		while (TRUE) {
+			gboolean _tmp4;
+			_tmp4 = FALSE;
+			if (self->priv->current < self->priv->end) {
+				_tmp4 = g_ascii_isdigit (self->priv->current[0]);
+			} else {
+				_tmp4 = FALSE;
+			}
+			if (!_tmp4) {
+				break;
+			}
+			self->priv->current++;
+		}
+	}
+	_tmp5 = FALSE;
+	_tmp6 = FALSE;
+	if (self->priv->current < (self->priv->end - 1)) {
+		_tmp6 = self->priv->current[0] == '.';
+	} else {
+		_tmp6 = FALSE;
+	}
+	if (_tmp6) {
+		_tmp5 = g_ascii_isdigit (self->priv->current[1]);
+	} else {
+		_tmp5 = FALSE;
+	}
+	/* fractional part*/
+	if (_tmp5) {
+		type = VALA_TOKEN_TYPE_REAL_LITERAL;
+		self->priv->current++;
+		while (TRUE) {
+			gboolean _tmp7;
+			_tmp7 = FALSE;
+			if (self->priv->current < self->priv->end) {
+				_tmp7 = g_ascii_isdigit (self->priv->current[0]);
+			} else {
+				_tmp7 = FALSE;
+			}
+			if (!_tmp7) {
+				break;
+			}
+			self->priv->current++;
+		}
+	}
+	_tmp8 = FALSE;
+	if (self->priv->current < self->priv->end) {
+		_tmp8 = g_ascii_tolower (self->priv->current[0]) == 'e';
+	} else {
+		_tmp8 = FALSE;
+	}
+	/* exponent part*/
+	if (_tmp8) {
+		gboolean _tmp9;
+		type = VALA_TOKEN_TYPE_REAL_LITERAL;
+		self->priv->current++;
+		_tmp9 = FALSE;
+		if (self->priv->current < self->priv->end) {
+			gboolean _tmp10;
+			_tmp10 = FALSE;
+			if (self->priv->current[0] == '+') {
+				_tmp10 = TRUE;
+			} else {
+				_tmp10 = self->priv->current[0] == '-';
+			}
+			_tmp9 = _tmp10;
+		} else {
+			_tmp9 = FALSE;
+		}
+		if (_tmp9) {
+			self->priv->current++;
+		}
+		while (TRUE) {
+			gboolean _tmp11;
+			_tmp11 = FALSE;
+			if (self->priv->current < self->priv->end) {
+				_tmp11 = g_ascii_isdigit (self->priv->current[0]);
+			} else {
+				_tmp11 = FALSE;
+			}
+			if (!_tmp11) {
+				break;
+			}
+			self->priv->current++;
+		}
+	}
+	/* type suffix*/
+	if (self->priv->current < self->priv->end) {
+		gboolean real_literal;
+		gboolean _tmp15;
+		real_literal = type == VALA_TOKEN_TYPE_REAL_LITERAL;
+		switch (self->priv->current[0]) {
+			case 'l':
+			case 'L':
+			{
+				if (type == VALA_TOKEN_TYPE_INTEGER_LITERAL) {
+					gboolean _tmp12;
+					self->priv->current++;
+					_tmp12 = FALSE;
+					if (self->priv->current < self->priv->end) {
+						_tmp12 = g_ascii_tolower (self->priv->current[0]) == 'l';
+					} else {
+						_tmp12 = FALSE;
+					}
+					if (_tmp12) {
+						self->priv->current++;
+					}
+				}
+				break;
+			}
+			case 'u':
+			case 'U':
+			{
+				if (type == VALA_TOKEN_TYPE_INTEGER_LITERAL) {
+					gboolean _tmp13;
+					self->priv->current++;
+					_tmp13 = FALSE;
+					if (self->priv->current < self->priv->end) {
+						_tmp13 = g_ascii_tolower (self->priv->current[0]) == 'l';
+					} else {
+						_tmp13 = FALSE;
+					}
+					if (_tmp13) {
+						gboolean _tmp14;
+						self->priv->current++;
+						_tmp14 = FALSE;
+						if (self->priv->current < self->priv->end) {
+							_tmp14 = g_ascii_tolower (self->priv->current[0]) == 'l';
+						} else {
+							_tmp14 = FALSE;
+						}
+						if (_tmp14) {
+							self->priv->current++;
+						}
+					}
+				}
+				break;
+			}
+			case 'f':
+			case 'F':
+			case 'd':
+			case 'D':
+			{
+				type = VALA_TOKEN_TYPE_REAL_LITERAL;
+				self->priv->current++;
+				break;
+			}
+		}
+		_tmp15 = FALSE;
+		if (!real_literal) {
+			_tmp15 = vala_scanner_is_ident_char (self, self->priv->current[0]);
+		} else {
+			_tmp15 = FALSE;
+		}
+		if (_tmp15) {
+			while (TRUE) {
+				gboolean _tmp16;
+				_tmp16 = FALSE;
+				if (self->priv->current < self->priv->end) {
+					_tmp16 = vala_scanner_is_ident_char (self, self->priv->current[0]);
+				} else {
+					_tmp16 = FALSE;
+				}
+				if (!_tmp16) {
+					break;
+				}
+				self->priv->current++;
+			}
+			type = VALA_TOKEN_TYPE_IDENTIFIER;
+		}
+	}
+	return type;
+}
+
+
 ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* token_begin, ValaSourceLocation* token_end) {
 	ValaTokenType type;
 	gchar* begin;
@@ -733,223 +954,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 				type = VALA_TOKEN_TYPE_IDENTIFIER;
 			} else {
 				if (g_ascii_isdigit (self->priv->current[0])) {
-					gboolean _tmp4;
-					while (TRUE) {
-						gboolean _tmp3;
-						_tmp3 = FALSE;
-						if (self->priv->current < self->priv->end) {
-							_tmp3 = g_ascii_isdigit (self->priv->current[0]);
-						} else {
-							_tmp3 = FALSE;
-						}
-						if (!_tmp3) {
-							break;
-						}
-						self->priv->current++;
-					}
-					type = VALA_TOKEN_TYPE_INTEGER_LITERAL;
-					_tmp4 = FALSE;
-					if (self->priv->current < self->priv->end) {
-						_tmp4 = g_ascii_tolower (self->priv->current[0]) == 'l';
-					} else {
-						_tmp4 = FALSE;
-					}
-					if (_tmp4) {
-						gboolean _tmp5;
-						self->priv->current++;
-						_tmp5 = FALSE;
-						if (self->priv->current < self->priv->end) {
-							_tmp5 = g_ascii_tolower (self->priv->current[0]) == 'l';
-						} else {
-							_tmp5 = FALSE;
-						}
-						if (_tmp5) {
-							self->priv->current++;
-						}
-					} else {
-						gboolean _tmp6;
-						_tmp6 = FALSE;
-						if (self->priv->current < self->priv->end) {
-							_tmp6 = g_ascii_tolower (self->priv->current[0]) == 'u';
-						} else {
-							_tmp6 = FALSE;
-						}
-						if (_tmp6) {
-							gboolean _tmp7;
-							self->priv->current++;
-							_tmp7 = FALSE;
-							if (self->priv->current < self->priv->end) {
-								_tmp7 = g_ascii_tolower (self->priv->current[0]) == 'l';
-							} else {
-								_tmp7 = FALSE;
-							}
-							if (_tmp7) {
-								gboolean _tmp8;
-								self->priv->current++;
-								_tmp8 = FALSE;
-								if (self->priv->current < self->priv->end) {
-									_tmp8 = g_ascii_tolower (self->priv->current[0]) == 'l';
-								} else {
-									_tmp8 = FALSE;
-								}
-								if (_tmp8) {
-									self->priv->current++;
-								}
-							}
-						} else {
-							gboolean _tmp9;
-							gboolean _tmp10;
-							_tmp9 = FALSE;
-							_tmp10 = FALSE;
-							if (self->priv->current < (self->priv->end - 1)) {
-								_tmp10 = self->priv->current[0] == '.';
-							} else {
-								_tmp10 = FALSE;
-							}
-							if (_tmp10) {
-								_tmp9 = g_ascii_isdigit (self->priv->current[1]);
-							} else {
-								_tmp9 = FALSE;
-							}
-							if (_tmp9) {
-								gboolean _tmp12;
-								gboolean _tmp16;
-								self->priv->current++;
-								while (TRUE) {
-									gboolean _tmp11;
-									_tmp11 = FALSE;
-									if (self->priv->current < self->priv->end) {
-										_tmp11 = g_ascii_isdigit (self->priv->current[0]);
-									} else {
-										_tmp11 = FALSE;
-									}
-									if (!_tmp11) {
-										break;
-									}
-									self->priv->current++;
-								}
-								_tmp12 = FALSE;
-								if (self->priv->current < self->priv->end) {
-									_tmp12 = g_ascii_tolower (self->priv->current[0]) == 'e';
-								} else {
-									_tmp12 = FALSE;
-								}
-								if (_tmp12) {
-									gboolean _tmp13;
-									self->priv->current++;
-									_tmp13 = FALSE;
-									if (self->priv->current < self->priv->end) {
-										gboolean _tmp14;
-										_tmp14 = FALSE;
-										if (self->priv->current[0] == '+') {
-											_tmp14 = TRUE;
-										} else {
-											_tmp14 = self->priv->current[0] == '-';
-										}
-										_tmp13 = (_tmp14);
-									} else {
-										_tmp13 = FALSE;
-									}
-									if (_tmp13) {
-										self->priv->current++;
-									}
-									while (TRUE) {
-										gboolean _tmp15;
-										_tmp15 = FALSE;
-										if (self->priv->current < self->priv->end) {
-											_tmp15 = g_ascii_isdigit (self->priv->current[0]);
-										} else {
-											_tmp15 = FALSE;
-										}
-										if (!_tmp15) {
-											break;
-										}
-										self->priv->current++;
-									}
-								}
-								_tmp16 = FALSE;
-								if (self->priv->current < self->priv->end) {
-									_tmp16 = g_ascii_tolower (self->priv->current[0]) == 'f';
-								} else {
-									_tmp16 = FALSE;
-								}
-								if (_tmp16) {
-									self->priv->current++;
-								}
-								type = VALA_TOKEN_TYPE_REAL_LITERAL;
-							} else {
-								gboolean _tmp17;
-								gboolean _tmp18;
-								gboolean _tmp19;
-								gboolean _tmp20;
-								_tmp17 = FALSE;
-								_tmp18 = FALSE;
-								_tmp19 = FALSE;
-								_tmp20 = FALSE;
-								if (self->priv->current < self->priv->end) {
-									_tmp20 = self->priv->current == (begin + 1);
-								} else {
-									_tmp20 = FALSE;
-								}
-								if (_tmp20) {
-									_tmp19 = begin[0] == '0';
-								} else {
-									_tmp19 = FALSE;
-								}
-								if (_tmp19) {
-									_tmp18 = begin[1] == 'x';
-								} else {
-									_tmp18 = FALSE;
-								}
-								if (_tmp18) {
-									_tmp17 = g_ascii_isxdigit (begin[2]);
-								} else {
-									_tmp17 = FALSE;
-								}
-								if (_tmp17) {
-									/* hexadecimal integer literal*/
-									self->priv->current++;
-									while (TRUE) {
-										gboolean _tmp21;
-										_tmp21 = FALSE;
-										if (self->priv->current < self->priv->end) {
-											_tmp21 = g_ascii_isxdigit (self->priv->current[0]);
-										} else {
-											_tmp21 = FALSE;
-										}
-										if (!_tmp21) {
-											break;
-										}
-										self->priv->current++;
-									}
-								} else {
-									gboolean _tmp22;
-									_tmp22 = FALSE;
-									if (self->priv->current < self->priv->end) {
-										_tmp22 = vala_scanner_is_ident_char (self, self->priv->current[0]);
-									} else {
-										_tmp22 = FALSE;
-									}
-									if (_tmp22) {
-										while (TRUE) {
-											gboolean _tmp23;
-											_tmp23 = FALSE;
-											if (self->priv->current < self->priv->end) {
-												_tmp23 = vala_scanner_is_ident_char (self, self->priv->current[0]);
-											} else {
-												_tmp23 = FALSE;
-											}
-											if (!_tmp23) {
-												break;
-											}
-											self->priv->current++;
-										}
-										type = VALA_TOKEN_TYPE_IDENTIFIER;
-									}
-								}
-							}
-						}
-					}
+					type = vala_scanner_read_number (self);
 				} else {
 					switch (self->priv->current[0]) {
 						case '{':
@@ -993,32 +998,32 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 							type = VALA_TOKEN_TYPE_DOT;
 							self->priv->current++;
 							if (self->priv->current < (self->priv->end - 1)) {
-								gboolean _tmp24;
-								_tmp24 = FALSE;
+								gboolean _tmp3;
+								_tmp3 = FALSE;
 								if (self->priv->current[0] == '.') {
-									_tmp24 = self->priv->current[1] == '.';
+									_tmp3 = self->priv->current[1] == '.';
 								} else {
-									_tmp24 = FALSE;
+									_tmp3 = FALSE;
 								}
-								if (_tmp24) {
+								if (_tmp3) {
 									type = VALA_TOKEN_TYPE_ELLIPSIS;
-									self->priv->current = self->priv->current + (2);
+									self->priv->current = self->priv->current + 2;
 								}
 							}
 							break;
 						}
 						case ':':
 						{
-							gboolean _tmp25;
+							gboolean _tmp4;
 							type = VALA_TOKEN_TYPE_COLON;
 							self->priv->current++;
-							_tmp25 = FALSE;
+							_tmp4 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp25 = self->priv->current[0] == ':';
+								_tmp4 = self->priv->current[0] == ':';
 							} else {
-								_tmp25 = FALSE;
+								_tmp4 = FALSE;
 							}
-							if (_tmp25) {
+							if (_tmp4) {
 								type = VALA_TOKEN_TYPE_DOUBLE_COLON;
 								self->priv->current++;
 							}
@@ -1094,16 +1099,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '^':
 						{
-							gboolean _tmp26;
+							gboolean _tmp5;
 							type = VALA_TOKEN_TYPE_CARRET;
 							self->priv->current++;
-							_tmp26 = FALSE;
+							_tmp5 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp26 = self->priv->current[0] == '=';
+								_tmp5 = self->priv->current[0] == '=';
 							} else {
-								_tmp26 = FALSE;
+								_tmp5 = FALSE;
 							}
-							if (_tmp26) {
+							if (_tmp5) {
 								type = VALA_TOKEN_TYPE_ASSIGN_BITWISE_XOR;
 								self->priv->current++;
 							}
@@ -1151,16 +1156,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 									}
 									case '<':
 									{
-										gboolean _tmp27;
+										gboolean _tmp6;
 										type = VALA_TOKEN_TYPE_OP_SHIFT_LEFT;
 										self->priv->current++;
-										_tmp27 = FALSE;
+										_tmp6 = FALSE;
 										if (self->priv->current < self->priv->end) {
-											_tmp27 = self->priv->current[0] == '=';
+											_tmp6 = self->priv->current[0] == '=';
 										} else {
-											_tmp27 = FALSE;
+											_tmp6 = FALSE;
 										}
-										if (_tmp27) {
+										if (_tmp6) {
 											type = VALA_TOKEN_TYPE_ASSIGN_SHIFT_LEFT;
 											self->priv->current++;
 										}
@@ -1172,16 +1177,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '>':
 						{
-							gboolean _tmp28;
+							gboolean _tmp7;
 							type = VALA_TOKEN_TYPE_OP_GT;
 							self->priv->current++;
-							_tmp28 = FALSE;
+							_tmp7 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp28 = self->priv->current[0] == '=';
+								_tmp7 = self->priv->current[0] == '=';
 							} else {
-								_tmp28 = FALSE;
+								_tmp7 = FALSE;
 							}
-							if (_tmp28) {
+							if (_tmp7) {
 								type = VALA_TOKEN_TYPE_OP_GE;
 								self->priv->current++;
 							}
@@ -1189,16 +1194,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '!':
 						{
-							gboolean _tmp29;
+							gboolean _tmp8;
 							type = VALA_TOKEN_TYPE_OP_NEG;
 							self->priv->current++;
-							_tmp29 = FALSE;
+							_tmp8 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp29 = self->priv->current[0] == '=';
+								_tmp8 = self->priv->current[0] == '=';
 							} else {
-								_tmp29 = FALSE;
+								_tmp8 = FALSE;
 							}
-							if (_tmp29) {
+							if (_tmp8) {
 								type = VALA_TOKEN_TYPE_OP_NE;
 								self->priv->current++;
 							}
@@ -1256,16 +1261,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '*':
 						{
-							gboolean _tmp30;
+							gboolean _tmp9;
 							type = VALA_TOKEN_TYPE_STAR;
 							self->priv->current++;
-							_tmp30 = FALSE;
+							_tmp9 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp30 = self->priv->current[0] == '=';
+								_tmp9 = self->priv->current[0] == '=';
 							} else {
-								_tmp30 = FALSE;
+								_tmp9 = FALSE;
 							}
-							if (_tmp30) {
+							if (_tmp9) {
 								type = VALA_TOKEN_TYPE_ASSIGN_MUL;
 								self->priv->current++;
 							}
@@ -1273,16 +1278,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '/':
 						{
-							gboolean _tmp31;
+							gboolean _tmp10;
 							type = VALA_TOKEN_TYPE_DIV;
 							self->priv->current++;
-							_tmp31 = FALSE;
+							_tmp10 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp31 = self->priv->current[0] == '=';
+								_tmp10 = self->priv->current[0] == '=';
 							} else {
-								_tmp31 = FALSE;
+								_tmp10 = FALSE;
 							}
-							if (_tmp31) {
+							if (_tmp10) {
 								type = VALA_TOKEN_TYPE_ASSIGN_DIV;
 								self->priv->current++;
 							}
@@ -1290,16 +1295,16 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						}
 						case '%':
 						{
-							gboolean _tmp32;
+							gboolean _tmp11;
 							type = VALA_TOKEN_TYPE_PERCENT;
 							self->priv->current++;
-							_tmp32 = FALSE;
+							_tmp11 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp32 = self->priv->current[0] == '=';
+								_tmp11 = self->priv->current[0] == '=';
 							} else {
-								_tmp32 = FALSE;
+								_tmp11 = FALSE;
 							}
-							if (_tmp32) {
+							if (_tmp11) {
 								type = VALA_TOKEN_TYPE_ASSIGN_PERCENT;
 								self->priv->current++;
 							}
@@ -1308,46 +1313,46 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 						case '\'':
 						case '"':
 						{
-							gboolean _tmp45;
+							gboolean _tmp24;
 							if (begin[0] == '\'') {
 								type = VALA_TOKEN_TYPE_CHARACTER_LITERAL;
 							} else {
-								gboolean _tmp33;
-								gboolean _tmp34;
-								_tmp33 = FALSE;
-								_tmp34 = FALSE;
+								gboolean _tmp12;
+								gboolean _tmp13;
+								_tmp12 = FALSE;
+								_tmp13 = FALSE;
 								if (self->priv->current < (self->priv->end - 6)) {
-									_tmp34 = begin[1] == '"';
+									_tmp13 = begin[1] == '"';
 								} else {
-									_tmp34 = FALSE;
+									_tmp13 = FALSE;
 								}
-								if (_tmp34) {
-									_tmp33 = begin[2] == '"';
+								if (_tmp13) {
+									_tmp12 = begin[2] == '"';
 								} else {
-									_tmp33 = FALSE;
+									_tmp12 = FALSE;
 								}
-								if (_tmp33) {
-									gboolean _tmp38;
-									gboolean _tmp39;
+								if (_tmp12) {
+									gboolean _tmp17;
+									gboolean _tmp18;
 									type = VALA_TOKEN_TYPE_VERBATIM_STRING_LITERAL;
 									token_length_in_chars = 6;
-									self->priv->current = self->priv->current + (3);
+									self->priv->current = self->priv->current + 3;
 									while (self->priv->current < (self->priv->end - 4)) {
-										gboolean _tmp35;
-										gboolean _tmp36;
-										_tmp35 = FALSE;
-										_tmp36 = FALSE;
+										gboolean _tmp14;
+										gboolean _tmp15;
+										_tmp14 = FALSE;
+										_tmp15 = FALSE;
 										if (self->priv->current[0] == '"') {
-											_tmp36 = self->priv->current[1] == '"';
+											_tmp15 = self->priv->current[1] == '"';
 										} else {
-											_tmp36 = FALSE;
+											_tmp15 = FALSE;
 										}
-										if (_tmp36) {
-											_tmp35 = self->priv->current[2] == '"';
+										if (_tmp15) {
+											_tmp14 = self->priv->current[2] == '"';
 										} else {
-											_tmp35 = FALSE;
+											_tmp14 = FALSE;
 										}
-										if (_tmp35) {
+										if (_tmp14) {
 											break;
 										} else {
 											if (self->priv->current[0] == '\n') {
@@ -1357,38 +1362,38 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 												token_length_in_chars = 3;
 											} else {
 												gunichar u;
-												u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+												u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 												if (u != ((gunichar) (-1))) {
-													self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+													self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 													token_length_in_chars++;
 												} else {
-													ValaSourceReference* _tmp37;
-													_tmp37 = NULL;
-													vala_report_error (_tmp37 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
-													(_tmp37 == NULL) ? NULL : (_tmp37 = (vala_source_reference_unref (_tmp37), NULL));
+													ValaSourceReference* _tmp16;
+													_tmp16 = NULL;
+													vala_report_error (_tmp16 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
+													(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_source_reference_unref (_tmp16), NULL));
 												}
 											}
 										}
 									}
-									_tmp38 = FALSE;
-									_tmp39 = FALSE;
+									_tmp17 = FALSE;
+									_tmp18 = FALSE;
 									if (self->priv->current[0] == '"') {
-										_tmp39 = self->priv->current[1] == '"';
+										_tmp18 = self->priv->current[1] == '"';
 									} else {
-										_tmp39 = FALSE;
+										_tmp18 = FALSE;
 									}
-									if (_tmp39) {
-										_tmp38 = self->priv->current[2] == '"';
+									if (_tmp18) {
+										_tmp17 = self->priv->current[2] == '"';
 									} else {
-										_tmp38 = FALSE;
+										_tmp17 = FALSE;
 									}
-									if (_tmp38) {
-										self->priv->current = self->priv->current + (3);
+									if (_tmp17) {
+										self->priv->current = self->priv->current + 3;
 									} else {
-										ValaSourceReference* _tmp40;
-										_tmp40 = NULL;
-										vala_report_error (_tmp40 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "syntax error, expected \"\"\"");
-										(_tmp40 == NULL) ? NULL : (_tmp40 = (vala_source_reference_unref (_tmp40), NULL));
+										ValaSourceReference* _tmp19;
+										_tmp19 = NULL;
+										vala_report_error (_tmp19 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "syntax error, expected \"\"\"");
+										(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_source_reference_unref (_tmp19), NULL));
 									}
 									break;
 								} else {
@@ -1398,39 +1403,39 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 							token_length_in_chars = 2;
 							self->priv->current++;
 							while (TRUE) {
-								gboolean _tmp41;
-								_tmp41 = FALSE;
+								gboolean _tmp20;
+								_tmp20 = FALSE;
 								if (self->priv->current < self->priv->end) {
-									_tmp41 = self->priv->current[0] != begin[0];
+									_tmp20 = self->priv->current[0] != begin[0];
 								} else {
-									_tmp41 = FALSE;
+									_tmp20 = FALSE;
 								}
-								if (!_tmp41) {
+								if (!_tmp20) {
 									break;
 								}
 								if (self->priv->current[0] == '\\') {
-									gboolean _tmp42;
+									gboolean _tmp21;
 									self->priv->current++;
 									token_length_in_chars++;
-									_tmp42 = FALSE;
+									_tmp21 = FALSE;
 									if (self->priv->current < self->priv->end) {
-										_tmp42 = self->priv->current[0] == 'x';
+										_tmp21 = self->priv->current[0] == 'x';
 									} else {
-										_tmp42 = FALSE;
+										_tmp21 = FALSE;
 									}
-									if (_tmp42) {
+									if (_tmp21) {
 										/* hexadecimal escape character*/
 										self->priv->current++;
 										token_length_in_chars++;
 										while (TRUE) {
-											gboolean _tmp43;
-											_tmp43 = FALSE;
+											gboolean _tmp22;
+											_tmp22 = FALSE;
 											if (self->priv->current < self->priv->end) {
-												_tmp43 = g_ascii_isxdigit (self->priv->current[0]);
+												_tmp22 = g_ascii_isxdigit (self->priv->current[0]);
 											} else {
-												_tmp43 = FALSE;
+												_tmp22 = FALSE;
 											}
-											if (!_tmp43) {
+											if (!_tmp22) {
 												break;
 											}
 											self->priv->current++;
@@ -1445,54 +1450,54 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 										break;
 									} else {
 										gunichar u;
-										u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+										u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 										if (u != ((gunichar) (-1))) {
-											self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+											self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 											token_length_in_chars++;
 										} else {
-											ValaSourceReference* _tmp44;
-											_tmp44 = NULL;
-											vala_report_error (_tmp44 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
-											(_tmp44 == NULL) ? NULL : (_tmp44 = (vala_source_reference_unref (_tmp44), NULL));
+											ValaSourceReference* _tmp23;
+											_tmp23 = NULL;
+											vala_report_error (_tmp23 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
+											(_tmp23 == NULL) ? NULL : (_tmp23 = (vala_source_reference_unref (_tmp23), NULL));
 										}
 									}
 								}
 							}
-							_tmp45 = FALSE;
+							_tmp24 = FALSE;
 							if (self->priv->current < self->priv->end) {
-								_tmp45 = self->priv->current[0] != '\n';
+								_tmp24 = self->priv->current[0] != '\n';
 							} else {
-								_tmp45 = FALSE;
+								_tmp24 = FALSE;
 							}
-							if (_tmp45) {
+							if (_tmp24) {
 								self->priv->current++;
 							} else {
-								char* _tmp47;
-								ValaSourceReference* _tmp46;
-								_tmp47 = NULL;
-								_tmp46 = NULL;
-								vala_report_error (_tmp46 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), _tmp47 = g_strdup_printf ("syntax error, expected %c", (gint) begin[0]));
-								_tmp47 = (g_free (_tmp47), NULL);
-								(_tmp46 == NULL) ? NULL : (_tmp46 = (vala_source_reference_unref (_tmp46), NULL));
+								char* _tmp26;
+								ValaSourceReference* _tmp25;
+								_tmp26 = NULL;
+								_tmp25 = NULL;
+								vala_report_error (_tmp25 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), _tmp26 = g_strdup_printf ("syntax error, expected %c", (gint) begin[0]));
+								_tmp26 = (g_free (_tmp26), NULL);
+								(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_source_reference_unref (_tmp25), NULL));
 							}
 							break;
 						}
 						default:
 						{
 							gunichar u;
-							u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+							u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 							if (u != ((gunichar) (-1))) {
-								ValaSourceReference* _tmp48;
-								self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
-								_tmp48 = NULL;
-								vala_report_error (_tmp48 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected character");
-								(_tmp48 == NULL) ? NULL : (_tmp48 = (vala_source_reference_unref (_tmp48), NULL));
+								ValaSourceReference* _tmp27;
+								self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
+								_tmp27 = NULL;
+								vala_report_error (_tmp27 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected character");
+								(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_source_reference_unref (_tmp27), NULL));
 							} else {
-								ValaSourceReference* _tmp49;
+								ValaSourceReference* _tmp28;
 								self->priv->current++;
-								_tmp49 = NULL;
-								vala_report_error (_tmp49 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "invalid UTF-8 character");
-								(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_source_reference_unref (_tmp49), NULL));
+								_tmp28 = NULL;
+								vala_report_error (_tmp28 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "invalid UTF-8 character");
+								(_tmp28 == NULL) ? NULL : (_tmp28 = (vala_source_reference_unref (_tmp28), NULL));
 							}
 							self->priv->column++;
 							return vala_scanner_read_token (self, &(*token_begin), &(*token_end));
@@ -1505,7 +1510,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 	if (token_length_in_chars < 0) {
 		self->priv->column = self->priv->column + ((gint) (self->priv->current - begin));
 	} else {
-		self->priv->column = self->priv->column + (token_length_in_chars);
+		self->priv->column = self->priv->column + token_length_in_chars;
 	}
 	(*token_end).pos = self->priv->current;
 	(*token_end).line = self->priv->line;
@@ -1582,7 +1587,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 		} else {
 			_tmp2 = FALSE;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	}
 	if (_tmp0) {
 		return FALSE;
@@ -1591,7 +1596,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 		gchar* begin;
 		char* _tmp5;
 		/* single-line comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		while (TRUE) {
 			gboolean _tmp4;
@@ -1607,14 +1612,14 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 			self->priv->current++;
 		}
 		_tmp5 = NULL;
-		vala_scanner_push_comment (self, _tmp5 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
+		vala_scanner_push_comment (self, _tmp5 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
 		_tmp5 = (g_free (_tmp5), NULL);
 	} else {
 		gchar* begin;
 		gint begin_line;
 		char* _tmp10;
 		/* delimited comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		begin_line = self->priv->line;
 		while (TRUE) {
@@ -1628,7 +1633,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 				} else {
 					_tmp7 = self->priv->current[1] != '/';
 				}
-				_tmp6 = (_tmp7);
+				_tmp6 = _tmp7;
 			} else {
 				_tmp6 = FALSE;
 			}
@@ -1650,10 +1655,10 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 			return TRUE;
 		}
 		_tmp10 = NULL;
-		vala_scanner_push_comment (self, _tmp10 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
+		vala_scanner_push_comment (self, _tmp10 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
 		_tmp10 = (g_free (_tmp10), NULL);
-		self->priv->current = self->priv->current + (2);
-		self->priv->column = self->priv->column + (2);
+		self->priv->current = self->priv->current + 2;
+		self->priv->column = self->priv->column + 2;
 	}
 	return TRUE;
 }
@@ -1705,7 +1710,7 @@ static void vala_scanner_push_comment (ValaScanner* self, const char* comment_it
  * @return saved comment
  */
 char* vala_scanner_pop_comment (ValaScanner* self) {
-	GString* result;
+	GString* result_builder;
 	char* _tmp1;
 	const char* index;
 	const char* _tmp2;
@@ -1714,16 +1719,16 @@ char* vala_scanner_pop_comment (ValaScanner* self) {
 	if (self->priv->_comment == NULL) {
 		return NULL;
 	}
-	result = g_string_new (self->priv->_comment);
+	result_builder = g_string_new (self->priv->_comment);
 	_tmp1 = NULL;
 	self->priv->_comment = (_tmp1 = NULL, self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp1);
 	index = NULL;
-	while ((index = g_utf8_strchr (result->str, (glong) (-1), (gunichar) '\t')) != NULL) {
-		g_string_erase (result, g_utf8_pointer_to_offset (result->str, index), (glong) 1);
+	while ((index = g_utf8_strchr (result_builder->str, (glong) (-1), (gunichar) '\t')) != NULL) {
+		g_string_erase (result_builder, g_utf8_pointer_to_offset (result_builder->str, index), (glong) 1);
 	}
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = result->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result == NULL) ? NULL : (result = (g_string_free (result, TRUE), NULL)), _tmp3);
+	return (_tmp3 = (_tmp2 = result_builder->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp3);
 }
 
 
